<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

<!-- Named templates -->
<xsl:template name="Sanskrit-wrap">
   <xsl:param name="contents">
     <xsl:apply-templates/>
   </xsl:param>
   <xsl:choose>
     <xsl:when test="@lang = 'sa'">
       <span style="font-family: 'Times Ext Roman'">
         <xsl:copy-of select="$contents"/>
       </span>
     </xsl:when>
     <xsl:otherwise>
       <xsl:copy-of select="$contents"/>
     </xsl:otherwise>
   </xsl:choose>
</xsl:template>

<!-- KCanon-specific Elements -->

   <xsl:template match="transDesc">
    <p style="margin-left:8mm; font-size:12pt; margin-top:0; margin-bottom:0; line-height:6mm">
      <xsl:apply-templates/>
    </p>
   </xsl:template>
   
      <xsl:template match="editionGrp">
     <table style="font-size: 12pt; margin-right:auto; border-width:0"><tr>
      <xsl:apply-templates/></tr></table>
      </xsl:template>

   
      <xsl:template match="edition">
        <xsl:choose>
          <xsl:when test="parent::editionGrp">
     <td style="padding-left:2em;padding-right:2em">(<xsl:apply-templates/>)</td>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates/>
            </xsl:otherwise></xsl:choose>
      </xsl:template>

  <xsl:template match="listBibl">
    <ul  style="list-style-type: none; margin-top:0.5em; margin-bottom:0.5em">
      <xsl:apply-templates/>
    </ul>
      </xsl:template>
 
  <xsl:template match="bibl">
      <xsl:choose>
     <xsl:when test="ancestor::listBibl">    
    <li style="line-height:6mm; margin-top:0; margin-bottom:0">
      <xsl:apply-templates/></li>
</xsl:when>
      <xsl:otherwise>
       <xsl:apply-templates/>
       </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  
<xsl:variable name="cjksource">Chinese Source Text</xsl:variable>



   <xsl:template match="p">
<xsl:choose>
<xsl:when test="@rend='blockquote'">
    <p style="margin-left:10mm; margin-top:1em; margin-bottom:1em;
 text-indent:0mm; margin-right:2mm; font-size:12pt; line-height:7mm">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
  <xsl:when test="@rend='indented'">
    <p style="font-size:12pt; text-indent:12mm; margin-top: 0;
 margin-bottom: 0; line-height:8mm">
      <xsl:apply-templates/>
    </p>
    </xsl:when>
  <xsl:when test="@rend='indented-italic'">
    <p style="font-size:12pt; text-indent:12mm; margin-top: 0;
 margin-bottom: 0; line-height:7mm; font-style: italic">
      <xsl:apply-templates/>
    </p>
    </xsl:when>
  <xsl:when test="@rend='hangInd'">
    <p style="text-indent:-10mm;margin-left:10mm">
      <xsl:apply-templates/>
    </p>
    </xsl:when>
     <xsl:when test="@rend='indHangInd'">
    <p style="text-indent:-10mm;margin-left:15mm">
      <xsl:apply-templates/>
    </p>
    </xsl:when>
  <xsl:when test="@rend='plain'">
    <p style="font-size:12pt; margin-left:0; margin-top:0; margin-bottom:0; text-indent:0mm; line-height:7mm">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
  <xsl:when test="@rend='plain-tight'">
    <p style="font-size:12pt; margin-left:0; margin-top:0; margin-bottom:0; text-indent:0mm; line-height:6mm">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
    <xsl:when test="@rend='centered'">
    <p style="text-align:center">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
      <xsl:when test="@rend='centered-xlarge'">
    <p style="text-align:center; font-size: 24pt">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
      <xsl:when test="@rend='centered-vlarge'">
    <p style="text-align:center; font-size: 18pt">
      <xsl:apply-templates/>
    </p>
  </xsl:when>

      <xsl:when test="@rend='centered-large'">
    <p style="text-align:center; font-size: 16pt">
      <xsl:apply-templates/>
    </p>
  </xsl:when> 

 <xsl:when test="@rend='plain-block'">
    <p style="font-size:12pt; margin-left:0; margin-top:1em; margin-bottom:0; text-indent:0mm; line-height:7mm">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
  <xsl:when test="@rend='italic'">
    <p style="font-style:italic">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
  <xsl:when test="@rend='bold'">
    <p style="font-weight:bold">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
<xsl:when test="@rend='epigram'">
     <p style="font-size:10pt; line-height:5mm; margin-bottom:0; margin-top:0"><xsl:apply-templates/></p>
</xsl:when>
  <xsl:when test="@rend='epigram-ref'">
    <p style="font-size:10pt; text-align:right; margin-top:0">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
  <xsl:when test="@rend='border-above'">
    <hr/>    <p class="plain">
      <xsl:apply-templates/>
    </p>
  </xsl:when>
  <xsl:when test="@rend='dbl-space'">
     <p style="font-size: 12pt; line-height:8mm">
      <xsl:apply-templates/>
    </p></xsl:when>
<xsl:when test="@rend='hide'">
   </xsl:when>
  <xsl:when test="@rend='showhide'">
   <xsl:variable name="cjknum" select="count(preceding::p[@rend='showhide'])+1"/>
<xsl:variable name="togglelabel" select="concat('chin','-',$cjknum)"/>
<span onclick="toggle('{$togglelabel}');return false;" style="font-size:11pt">[<a href="#"><xsl:value-of select="$cjksource"/></a>]</span> 
<div id="{$togglelabel}" style="display: none">
    <p style="font-style: MingLiU; font-size:14pt; margin-right:5em">
      <xsl:apply-templates/>
    </p></div>
  </xsl:when>


  <xsl:otherwise>
  <p>
      <xsl:apply-templates/>
  </p>
  </xsl:otherwise>
  </xsl:choose>
  </xsl:template>

<!-- Lists -->   
  <xsl:template match="list">
<xsl:choose>
<xsl:when test="@type='ordered'">
    <ol>
      <xsl:apply-templates/>
    </ol>
  </xsl:when>
  <xsl:when test="@type='bulleted'">
    <ul>
      <xsl:apply-templates/>
    </ul>
    </xsl:when>
  <xsl:when test="@type='simple'">
    <ul style="list-style-type: none">
      <xsl:apply-templates/>
    </ul>
  </xsl:when>
   <xsl:when test="@n='canonRefs'">
    <ul style="list-style-type: none; margin-left:12mm">
      <xsl:apply-templates/>
    </ul>
    </xsl:when>
 
    <xsl:otherwise>
     <ul>
      <xsl:apply-templates/>
    </ul>
  </xsl:otherwise>
 </xsl:choose>
</xsl:template>
<xsl:template match="item">
  <li style="margin-bottom: 0.5em; margin-left:4mm"><xsl:apply-templates/></li>
</xsl:template>

<!-- <head>(s) -->

<xsl:template match="head">
       <xsl:if test="parent::catEntry">
 <hr/>
      <p style="text-align:center; font-style:italic">
          <xsl:apply-templates/>
</p>
       </xsl:if>
           <xsl:if test="parent::div0">
      <p style="font-size:24pt; text-align:center">
        <xsl:apply-templates/>
      </p>
    </xsl:if>
    <xsl:if test="parent::div2">
      <p class="head2web">
        <xsl:apply-templates/>
      </p>
    </xsl:if>
    <xsl:if test="parent::div3">
      <p class="head3web">
        <xsl:apply-templates/>
      </p>
    </xsl:if>
</xsl:template>

<!-- Bibliographical renderings -->

  <xsl:template match="biblStruct">
    <p class="hangInd"><xsl:apply-templates/></p>
    </xsl:template>
  
<xsl:template match="author">

<!-- MB 2003-08-01
* * If our author name is the same as the preceding one, output
** a string of dashes in its place. NB this presupposes that identical
**  names are indeed entered identically! It might also be a wise
** precaution to normalize-space both the string values we are
** comparing. Also, the "suppression marker" perhaps ought to be
** in a variable rather than hard-coded as here.
-->

<xsl:choose>
  <xsl:when test="preceding::biblStruct[1]/*/author = .">
       <xsl:text>----.&#160;</xsl:text>
  </xsl:when>
   <xsl:when test="substring(., string-length(.)) = '.'">
     <xsl:apply-templates/>
 <xsl:text>&#160;</xsl:text>
  </xsl:when>
 <xsl:otherwise>
  <xsl:apply-templates/><xsl:text>.&#160;</xsl:text>
  </xsl:otherwise>
</xsl:choose>
</xsl:template>
  <xsl:template match="monogr[@rend]">
    <xsl:variable name="monogrnote" select="@rend"/>
    <xsl:value-of select="$monogrnote"/><xsl:text> </xsl:text><xsl:apply-templates/>
    </xsl:template>

  <xsl:template match="imprint[@rend]">
    <xsl:variable name="imprintnote" select="@rend"/>
    [<xsl:value-of select="$imprintnote"/><xsl:text>: </xsl:text><xsl:apply-templates/>]
    </xsl:template>

 <xsl:template match="editor">
<xsl:choose>
  <xsl:when test="preceding::biblStruct[1]/*/editor = .">
       <xsl:text>----, ed.&#160;</xsl:text>
  </xsl:when>
 <xsl:otherwise>
  <xsl:apply-templates/>
  </xsl:otherwise>
</xsl:choose></xsl:template>


 <xsl:template match="date">
    <xsl:if test="(parent::p)">
    <xsl:apply-templates/>
  </xsl:if>
    <xsl:apply-templates/>. 
</xsl:template>

  <xsl:template match="pubPlace">
    <xsl:apply-templates/>:&#160;
</xsl:template>
  <xsl:template match="publisher">
    <xsl:apply-templates/>,&#160;
</xsl:template>

 <xsl:template match="biblScope">
    <xsl:choose>
      <xsl:when test="ancestor::listBibl">
        <xsl:if test="@type='vol'">
          vol. <xsl:apply-templates/>, 
        </xsl:if>
        <xsl:if test="@type='pages'">
          pages <xsl:apply-templates/>. 
        </xsl:if>
               <xsl:if test="@type='fascicles'">
          <xsl:text> </xsl:text>(<xsl:apply-templates/>)
               </xsl:if>
</xsl:when>
      <xsl:when test="ancestor::cit">
(<xsl:apply-templates/>) 
      </xsl:when>
      <xsl:when test="ancestor::p">
(<xsl:apply-templates/>) 
    </xsl:when>
      <xsl:when test="ancestor::quote">
(<xsl:apply-templates/>) 
      </xsl:when>
           <xsl:when test="@lang='bo'">
<span style="font-style:italic; font-family: Times Ext Roman"><xsl:apply-templates/> </span>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates/>
    </xsl:otherwise></xsl:choose></xsl:template>


<xsl:template match="title">
   <xsl:call-template name="Sanskrit-wrap">
     <xsl:with-param name="contents">
       <xsl:choose>
         <xsl:when test="ancestor::listBibl">
            <xsl:choose>
              <xsl:when test="@level='m' or @level='j' or @level='s'">
                 <span style="font-style:italic"><xsl:apply-templates/>. </span>
              </xsl:when>
                <xsl:when test="@level='a' or @level='u'">&quot;<xsl:apply-templates/>.&quot; </xsl:when>
              <xsl:when test="@rend='bold'">
                <span style="font-weight:bold"><xsl:apply-templates/></span>
              </xsl:when>
              <xsl:when test="@type='parallel'">
                (<span style="font-style:italic"><xsl:apply-templates/></span>)
              </xsl:when>
               <xsl:when test="@system='hg'">
               <span style="font-family:Batang, Dotum"><xsl:apply-templates/></span>
               </xsl:when>
                        <xsl:when test="@lang='cjk'">
               <span style="font-family:MingLiu"><xsl:apply-templates/></span>
                        </xsl:when>
               <xsl:when test="@lang='bo'">
               <span style="font-style:italic; font-family:Times Ext Roman"><xsl:apply-templates/></span>
              </xsl:when>
              <xsl:otherwise>
                <span style="font-style:italic"><xsl:apply-templates/></span>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:otherwise>
            <xsl:choose>
               <xsl:when test="@level='m' or @level='j' or @level='s'">
                  <span style="font-style:italic"><xsl:apply-templates/></span>
              </xsl:when>
                <xsl:when test="@level='a' or @level='u'">&quot;<xsl:apply-templates/>&quot;</xsl:when>
              <xsl:otherwise>
                <span style="font-style:italic"><xsl:apply-templates/></span>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:with-param>
    </xsl:call-template>
</xsl:template>

<xsl:template match="lg">
  <p class="plain">
   <xsl:apply-templates/>
  </p>
 </xsl:template>
<xsl:template match="l">
  <p class="verseline">
   <xsl:apply-templates/>
  </p>
 </xsl:template>

  <xsl:template match="foreign">
   <xsl:call-template name="Sanskrit-wrap">
     <xsl:with-param name="contents">
       <xsl:choose>
          <xsl:when test="@level='m' or @level='j' or @level='s'">
    <span style="font-style:normal">
      <xsl:apply-templates/>
    </span>
  </xsl:when>
  <xsl:otherwise>
       <span style="font-style:italic">
      <xsl:apply-templates/>
    </span>
  </xsl:otherwise>
</xsl:choose>
  </xsl:with-param>
</xsl:call-template>
  </xsl:template>

  <xsl:template match="gloss">
    <xsl:choose>
      <xsl:when test="parent::title">
        <xsl:choose>
              <xsl:when test="@lang='sa'">
              <span style="font-style:italic"> (<xsl:apply-templates/>)</span>
            </xsl:when>
              <xsl:otherwise>
              <span style="font-style:normal"> (<xsl:apply-templates/>)</span>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
            <xsl:choose>
             <xsl:when test="gloss[@lang='cjk']">
            <span style="font-family:MingLiu;font-style:normal">
              <xsl:apply-templates/></span>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates/>
            </xsl:otherwise>
          </xsl:choose></xsl:otherwise></xsl:choose></xsl:template>
 
 <xsl:template match="emph">
   <xsl:choose>
     <xsl:when test="@rend='bold'">
   <span style="font-weight:bold"><xsl:apply-templates/></span>       
     </xsl:when>
     <xsl:otherwise>
    <span style="font-style:italic"><xsl:apply-templates/></span>       
     </xsl:otherwise>
 </xsl:choose>
  </xsl:template>

 <xsl:template match="hi">
   <xsl:choose>
     <xsl:when test="@rend='bold'">
   <span style="font-weight:bold"><xsl:apply-templates/></span>       
     </xsl:when>
     <xsl:when test="@rend='color-red'">
   <span style="color: rgb(204, 0, 0)"><xsl:apply-templates/></span>       
     </xsl:when>
     <xsl:when test="@rend='normal'">
          <span style="font-style: normal"><xsl:apply-templates/></span>     
     </xsl:when>
     <xsl:otherwise>
    <span style="font-style:italic"><xsl:apply-templates/></span>       
     </xsl:otherwise>
 </xsl:choose>
  </xsl:template>

  <xsl:template match="note">
    <xsl:choose>
      <xsl:when test="parent::biblStruct">
        (<xsl:apply-templates/>)
      </xsl:when>
      <xsl:when test="parent::monogr"><xsl:apply-templates/>,&#160;</xsl:when>
      <xsl:otherwise>
        <xsl:choose>
          <xsl:when test="@place='interlinear'">
    <span style="font-size:11pt">[Interlinear Note: 
   <xsl:apply-templates/>
]</span>
  </xsl:when>
  <xsl:when test="@place='bibl'">
    <xsl:apply-templates/>.&#160;
 </xsl:when>
<xsl:when test="@rend='paren'">
  (<xsl:apply-templates/>)
</xsl:when>
<xsl:when test="@rend='brackets'">
  [<xsl:apply-templates/>]
</xsl:when>
</xsl:choose>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

  <xsl:template match="quote">
  <xsl:choose>
  <xsl:when test="@rend='dq'">
 &quot;<xsl:apply-templates/>&quot;
</xsl:when>
<xsl:when test="@rend='dq-ul'">
  &quot;<span style="text-decoration:underline"><xsl:apply-templates/></span>&quot;
</xsl:when>
  <xsl:when test="@rend='sq'">
 '<xsl:apply-templates/>'
</xsl:when>
  <xsl:when test="@rend='brackets'">
「<xsl:apply-templates/>」
</xsl:when>
  <xsl:when test="@rend='block'">
    <xsl:choose>
      <xsl:when test="ancestor::note">
     <p style="font-size:11pt; margin-left:10mm; margin-top:1em; margin-bottom:1em; text-indent:0mm; margin-right:8mm; line-height:6mm">
      <xsl:apply-templates/>
    </p>       
      </xsl:when>
      <xsl:when test="parent::cit">
      <xsl:apply-templates/>
     </xsl:when>
      <xsl:otherwise>
     <p class="blockquote">
      <xsl:apply-templates/>
    </p>
      </xsl:otherwise>
    </xsl:choose>
</xsl:when>
      <xsl:otherwise>
     <p class="blockquote">
      <xsl:apply-templates/>
    </p>
      </xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="cit">
  <xsl:choose>
    <xsl:when test="child::quote[@rend='block']">
           <p class="blockquote">
      <xsl:apply-templates/>
    </p>
    </xsl:when>
    <xsl:otherwise>
            <xsl:apply-templates/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="soCalled">
  <xsl:choose>
    <xsl:when test="parent::quote[@rend='dq']">
      &apos;<xsl:apply-templates/>&apos;
  </xsl:when>
  <xsl:otherwise>
     &quot;<xsl:apply-templates/>&quot;
  </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- CM 2004-03-09 Start catEntry label handler, part 1-->
<!-- Get the catEntry id number into a variable -->


 <xsl:template match="label">
    <xsl:choose>
   <xsl:when test="@rend='knum'"><td>
    <span style="font-weight:bold">

<xsl:variable name="catEntrynum" select="ancestor::catEntry[1]/@id"/>
<!-- Now to write the anchor and hyperlink -->

<a>
<xsl:attribute name="name"><xsl:value-of select="$catEntrynum"/></xsl:attribute>

<!--        <xsl:if test="../@id">            
          <xsl:value-of select="../@id"/><xsl:text>. </xsl:text>
        </xsl:if>
 -->
 <xsl:apply-templates/>
        </a>
</span></td>
</xsl:when>

      <xsl:when test="@rend='italic'">
    <span style="font-style:italic"><xsl:apply-templates/></span>
  </xsl:when>
      <xsl:when test="@rend='bold'">
    <span style="font-weight:bold"><xsl:apply-templates/></span>
  </xsl:when>
     <xsl:when test="@rend='underline'">
    <span style="text-decoration:underline"><xsl:apply-templates/></span>
  </xsl:when>
     <xsl:when test="@rend='underline-colon'">
    <span style="text-decoration:underline"><xsl:apply-templates/>: </span>
  </xsl:when>
     <xsl:when test="@rend='color-red'">
   <span style="color: rgb(204, 0, 0); font-weight:bold">[<xsl:apply-templates/>]</span>       
     </xsl:when>
      <xsl:when test="@rend='brackets'">
        [<xsl:apply-templates/>]<xsl:text> </xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:apply-templates/>
  </xsl:otherwise>
</xsl:choose>
  </xsl:template>

<xsl:template match="label" mode="showlabels">
<xsl:variable name="catEntrynum" select="ancestor::catEntry[1]/@id"/>
<tr>
<!-- MB 2003-03-22
*   Output the reference no in a right-aligned table cell. This ensures correct
*   vertical alignment of the numbers, no matter how many places they have
*   The valign value of "top" ensures that that number will remain in the correct
*   horizontal alignment against the first line ot the title even if the title itself wraps
*  on to a second or even third line
-->
<td align="right" valign="top">
<!-- Leave the cell empty if we don't have a number (preventing an orphaned period)
-->
<!-- Don't need this one on the Lancaster catalogue

<xsl:if test="$catEntrynum">
<xsl:value-of select="$catEntrynum"/><xsl:text>. </xsl:text>
</xsl:if>

-->
</td>
<!-- write the <a>element target for the link reference. Use AVT notation to
*     insert the attribute value. Putting the title into a table cell ensures
*     all titles left-align correctly, no matter what the size of the numeral
*     (if any) that precedes them
-->
<td><a href="#{$catEntrynum}"><xsl:apply-templates/></a></td>    
</tr>

<!-- Finish Div handler, part 2 -->

  </xsl:template>

<xsl:template match="table">
    <xsl:choose>
    <xsl:when test="@rend='fullwidth'">
  <table width="100%" style="font-size:12pt"><xsl:apply-templates/></table>
    </xsl:when>
    <xsl:when test="@rend='90%'">
  <table width="90%" style="font-size:12pt" border="2"><xsl:apply-templates/></table>
    </xsl:when>
    <xsl:otherwise>
 <table><xsl:apply-templates/></table>
</xsl:otherwise></xsl:choose>
</xsl:template>

<xsl:template match="row">
  <tr><xsl:apply-templates/></tr>
</xsl:template>
<xsl:template match="cell">
  <td><xsl:apply-templates/></td>
</xsl:template>

</xsl:stylesheet>

